========
Glossary
========

.. glossary::
    :sorted:

    VCS
        Version Control System, what you use for versioning your source code

    NMEA
        National Marine Electronics Association [protocol] (org., USA, GPS), http://www.nmea.org

    GDAL
        GDAL is a translator library for raster geospatial data formats.
        As a library, it presents a single abstract data model to the
        calling application for all supported formats. The related OGR
        library (which lives within the GDAL source tree) provides
        a similar capability for simple features vector data.

        GDAL supports many popular data formats, including commonly used
        ones (:term:`GeoTIFF`, :term:`JPEG`, :term:`PNG` and more) as well as the ones used in
        GIS and remote sensing software packages (ERDAS Imagine,
        :term:`ESRI` Arc/Info, ENVI, PCI Geomatics). Also supported many remote
        sensing and scientific data distribution formats such as HDF,
        EOS FAST, :term:`NOAA` L1B, NetCDF, FITS.

        OGR library supports popular vector formats like ESRI Shapefile,
        TIGER data, :term:`S57`, MapInfo File, DGN, GML and more.

    GeoTIFF
        GeoTIFF is a public domain metadata standard which allows
        georeferencing information to be embedded within a TIFF file.

        The potential additional information includes map projection,
        coordinate systems, ellipsoids, datums, and everything else
        necessary to establish the exact spatial reference for the file.

    GPS
        a navigational system involving satellites and computers
        that can determine the latitude and longitude of a receiver
        on Earth by computing the time difference for signals from
        different satellites to reach the receiver [syn: {Global
        Positioning System}, {GPS}]

    JSON
        In computing, JavaScript Object Notation or JSON (/ˈdʒeɪsən/
        "jay-son", /dʒeɪˈsɒn/)[1] is an open-standard file format that
        uses human-readable text to transmit data objects consisting of
        attribute–value pairs and array data types (or any other
        serializable value). It is a very common data format used for
        asynchronous browser–server communication.

    LDAP
        Lightweight Directory Access Protocol (RFC 1777, X.500, DS, AD, CORBA)

    MQTT
        Message Queuing Telemetry Transport (ISO/IEC PRF 20922) is a publish-
        subscribe-based messaging protocol. It works on top of the TCP/IP
        protocol. It is designed for connections with remote locations
        where a "small code footprint" is required or the network bandwidth
        is limited. The publish-subscribe messaging pattern requires a message
        broker.
  
    Radar
        measuring instrument in which the echo of a pulse of
        microwave radiation is used to detect and locate distant
        objects [syn: {radar}, {microwave radar}, {radio detection
        and ranging}, {radiolocation}]
  
    XMPP
        Extensible Messaging and Presence Protocol (XMPP) is a communication
        protocol for message-oriented middleware based on XML (Extensible Markup
        Language).[1] It enables the near-real-time exchange of structured yet
        extensible data between any two or more network entities.

        Originally named Jabber, the protocol was developed by the Jabber
        open-source community in 1999 for near real-time instant messaging (IM),
        presence information, and contact list maintenance.

        Designed to be extensible, the protocol has been used also for publish-
        subscribe systems, signalling for VoIP, video, file transfer, gaming,
        the Internet of Things (IoT) applications such as the smart grid, and
        social networking services.
